This function creates a custom labeller for use
in ggplot2::facet_wrap() to format dates (typically yearmonth) in a
specified string format.
Value
A labeller function suitable for the labeller argument in gg_facet_wrap_months()
This function creates a custom labeller for use
in ggplot2::facet_wrap() to format dates (typically yearmonth) in a
specified string format.
A labeller function suitable for the labeller argument in gg_facet_wrap_months()